@@ -190,7 +190,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
                     if (nr > 0) {
                         buf[nr] = 0;
                         String mimestr = MimeType::findByContent (buf, nr);
-                        if (mimestr.startsWith (String ("text/")) &&
+                        if (!mimestr.startsWith (String ("text/")) ||
                                 !strncmp (buf, "RIFF", 4))
                             maybe_playlist = false;
                     }
@@ -286,6 +286,24 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
         } else if (line.stripWhiteSpace ().startsWith (Char ('<'))) {
             readXML (cur_elm, textstream, line);
             //cur_elm->normalize ();
+        } else if (line.lower ().startsWith ("[reference]")) {
+            NodePtr doc = node->document ();
+            for (line = textstream.readLine ();
+                    !line.isNull ();
+                    line = textstream.readLine ()) {
+                if (line.lower ().startsWith ("ref")) {
+                    int p = line.indexOf ("=", 3);
+                    if (p > -1) {
+                        URL u (line.mid (p + 1));
+                        if (u.protocol() == "http" &&
+                                line.indexOf("MSWMExt=.asf") > -1)
+                            cur_elm->appendChild (new GenericURL (doc,
+                                        String ("mms") + u.url().mid (4)));
+                        else if (u.protocol() == "mms")
+                            cur_elm->appendChild (new GenericURL(doc, u.url()));
+                    }
+                }
+            }
         } else if (line.lower () != "[reference]") {
             bool extm3u = line.startsWith ("#EXTM3U");
             String title;
@@ -709,12 +727,10 @@ void ImageActor::unpause () {
 
 KDE_NO_EXPORT
 void ImageActor::setupImage (const String &url, const ByteArray &data) {
-    GError *gerror = 0L;
-
     GdkPixbufLoader *pix_loader = gdk_pixbuf_loader_new ();
     if (gdk_pixbuf_loader_write (pix_loader,
                 (const guchar *) data.data (),
-                data.size (), &gerror) &&
+                data.size (), NULL) &&
             gdk_pixbuf_loader_close (pix_loader, 0L)) {
         cached_img = ImageDataPtr (new ImageData (url));
         img_movie = gdk_pixbuf_loader_get_animation (pix_loader);
@@ -734,7 +750,6 @@ void ImageActor::setupImage (const String &url, const ByteArray &data) {
         (*image_data_map)[url] = ImageDataPtrW (cached_img);
     }
     g_object_unref (pix_loader);
-    g_free (gerror);
 }
 
 bool ImageActor::isEmpty () const {
