@@ -100,7 +100,7 @@ void *SourceDocument::role (RoleType msg, void *data) {
 
 
 Control::Control (Application * a)
-    : m_process (0L), m_doc_timer (0), progress_banner (NULL),
+    : m_process (0L), m_doc_timer (0), progress_banner (NULL), mplayer (NULL),
       playlist_data (0L), m_config (new Config), m_app (a),
       paint_timer (0), update_tree_timer (0), blanking_timer (0),
       in_progress_update (false),
@@ -124,6 +124,7 @@ Control::~Control () {
 void Control::init () {
     unsigned int ver, rel, req, evb, err;
     struct stat st;
+    glob_t globbuf;
 
     use_xvideo = true;
    //media_server = new OssoMediaServer (this, m_app->osso_context, use_xvideo);
@@ -132,7 +133,9 @@ void Control::init () {
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
     media_server = gst;
-    mplayer = new MPlayer (this, "mplayer");
+    if (glob ("/usr/bin/mplayer", 0, NULL, &globbuf) != GLOB_NOMATCH)
+        mplayer = new MPlayer (this, "mplayer");
+    globfree (&globbuf);
 #ifdef __ARMEL__
     npp = new NpPlayer (this);
 #endif
@@ -143,7 +146,6 @@ void Control::init () {
 
     /*if (use_xvideo)
         use_xvideo = !m_config->readNumEntry (GCONF_KEY_VO, 0);
-    setUseXVideo (use_xvideo);
     if (!use_xvideo)
         gtk_check_menu_item_set_active (
                 GTK_CHECK_MENU_ITEM (m_app->menu_item_mplayer_vo), true);*/
@@ -247,8 +249,6 @@ void Control::deinit () {
         generators.remove (s);
     }
 
-    m_config->writeEntry (GCONF_KEY_VO, mplayer->hasXv () ? 0 : 1);
-
     viewArea ()->deleteEvent ();
 
     delete media_server;
@@ -511,7 +511,7 @@ bool Control::requestPlayURL (Mrl *mrl) {
 
 bool Control::setProcess (const char *pname) {
     Process *old_process = m_process;
-    if (!strcmp (pname, mplayer->name ())) {
+    if (mplayer && !strcmp (pname, mplayer->name ())) {
         m_process = mplayer;
 #ifdef __ARMEL__
     } else if (!strcmp (pname, npp->name ())) {
@@ -528,7 +528,6 @@ bool Control::setProcess (const char *pname) {
         else
             old_process->quit ();
     }
-    //setUseXVideo (use_xvideo);
 }
 
 bool Control::setProcess (Mrl *mrl) {
@@ -541,7 +540,7 @@ bool Control::setProcess (Mrl *mrl) {
     bool changed = false;
     if (id_node_playlist_item == mrl->id) {
         String p = mrl->getAttribute ("player");
-        if (p == mplayer->name () || p == media_server->name ()
+        if ((mplayer && p == mplayer->name ()) || p == media_server->name ()
 #ifdef __ARMEL__
                 || p == npp->name ()
 #endif
@@ -891,13 +890,6 @@ void Control::setAspect (float aspect) {
     updateViewAreaSizes ();
 }
 
-void Control::setUseXVideo (bool b) {
-    mplayer->setUseXv (b);
-    use_xvideo = b;
-    VIEWAREA(m_app)->setControlsOverlap (b || m_process != mplayer);
-    VIEWAREA(m_app)->enableVideoInputFilter (b && m_process == mplayer);
-}
-
 void cb_view_area_configure (GtkWidget *widget, GdkEventConfigure *event, Application * app) {
     //debugLog () << "cb_view_area_configure " << event->width<< "x" << event->height << endl;
     CONTROL(app)->updateViewAreaSizes ();
@@ -1037,6 +1029,9 @@ void cb_playlist_stop (GtkButton * button, void *p) {
     } else if (ctr->current_selected) {
         ctr->request_download = true;
         jump (ctr->current_selected, ctr);
+    } else {
+        hildon_banner_show_information (GTK_WIDGET (ctr->m_app->window), NULL,
+                "No Playlist Item Selected");
     }
 }
 
@@ -1345,30 +1340,30 @@ void playerMenuActivate (GtkMenuItem *item, Application *app) {
             G_CALLBACK (playerResponse), ctrl);
     hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
             ctrl->media_server->name ());
-    hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
-            ctrl->mplayer->name ());
-    if (player == ctrl->mplayer->name ())
-        idx = 1;
+    if (ctrl->mplayer) {
+        hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
+                ctrl->mplayer->name ());
+        if (player == ctrl->mplayer->name ())
+            idx = 1;
+    }
 #ifdef __ARMEL__
     hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
             ctrl->npp->name ());
     if (player == ctrl->npp->name ())
-        idx = 2;
+        idx = ctrl->mplayer ? 2 : 1;
 #endif
     hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, idx);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
     if (player != ctrl->selected_player) {
-        Process *p;
-        if (ctrl->selected_player == ctrl->media_server->name ())
-            p = ctrl->media_server;
+        Process *p = ctrl->media_server;
+        if (ctrl->mplayer && ctrl->selected_player == ctrl->mplayer->name ())
+            p = ctrl->mplayer;
 #ifdef __ARMEL__
         else if (ctrl->selected_player == ctrl->npp->name ())
             p = ctrl->npp;
 #endif
-        else
-            p = ctrl->mplayer;
         ctrl->setProcess (p->name ());
 #ifdef __ARMEL__
         if (p != ctrl->npp)
