@@ -92,8 +92,8 @@ TextStream &KMPlayer::operator << (TextStream &out, const XMLStringlet &txt) {
 
 //-----------------------------------------------------------------------------
 
-Connection::Connection (Node *invoker, Node *receiver)
- : connectee (invoker), connecter (receiver) {
+Connection::Connection (Node *invoker, Node *receiver, VirtualVoid *pl)
+ : connectee (invoker), connecter (receiver), payload (pl) {
 #ifdef KMPLAYER_TEST_CONNECTION
     connection_counter++;
 #endif
@@ -105,11 +105,12 @@ ConnectionLink::~ConnectionLink () {
     disconnect ();
 }
 
-bool ConnectionLink::connect (Node *send, MessageType msg, Node *rec) {
+bool ConnectionLink::connect (Node *send, MessageType msg, Node *rec,
+        VirtualVoid *payload) {
     disconnect ();
     ConnectionList *list = nodeMessageReceivers (send, msg);
     if (list) {
-        connection = new Connection (send, rec);
+        connection = new Connection (send, rec, payload);
         connection->list = list;
         connection->link = &connection;
         connection->prev = list->link_last;
@@ -390,7 +391,7 @@ void Node::normalize () {
 static void getInnerText (const Node *p, TextStream & out) {
     for (Node *e = p->firstChild (); e; e = e->nextSibling ()) {
         if (e->id == id_node_text || e->id == id_node_cdata)
-            out << e->nodeValue () << char_nl;
+            out << e->nodeValue ();
         else
             getInnerText (e, out);
     }
@@ -499,7 +500,7 @@ void Node::accept (Visitor * v) {
 }
 
 String Node::nodeValue () const {
-    return String ();
+    return innerText ().stripWhiteSpace ();
 }
 
 template <> void List<NodeRefItem>::remove (NodeRefItem *c) {
@@ -625,8 +626,16 @@ String Element::getAttribute (const TrieString & name) {
 
 void Element::init () {
     d->clear();
-    for (Attribute *a = attributes ().first (); a; a = a->nextSibling ())
-        parseParam (a->name (), a->value ());
+    for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
+        String v = a->value ();
+        int p = v.indexOf (Char ('{'));
+        if (p > -1) {
+            int q = v.indexOf (Char ('}'), p + 1);
+            if (q > -1)
+                continue;
+        }
+        parseParam (a->name (), v);
+    }
 }
 
 void Element::reset () {
