@@ -626,21 +626,22 @@ gboolean playlist_selected (Application *app, GValue *icon, GValue *text) {
 }
 
 void cb_treeCellDataFunc (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
-        GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer data) {
+        GtkTreeModel *tree_model, GtkTreeIter *iter, Application *app) {
     GtkTreeIter parent;
-    PlayListData * pld = getListData ((Application*)data, tree_model, iter);
+    PlayListData * pld = getListData (app, tree_model, iter);
     if (!gtk_tree_model_iter_parent (tree_model, &parent, iter) ) {
-        g_object_set (G_OBJECT (cell), "cell-background", "black", 0L);
+        g_object_set (G_OBJECT (cell), "cell-background-gtk",
+                app->playlist_view->style->black, 0L);
         g_object_set (G_OBJECT (cell), "background-gdk",
-                ((Application*)data)->playlist_view->style->bg + 1, 0L);
+                app->playlist_view->style->dark + 1, 0L);
         g_object_set (G_OBJECT (cell), "editable", false, 0L);
         g_object_set (G_OBJECT (cell), "mode",
                 GTK_CELL_RENDERER_MODE_ACTIVATABLE, 0L);
     } else if (pld) {
         g_object_set (G_OBJECT (cell), "cell-background-gdk",
-                ((Application*)data)->playlist_view->style->bg, 0L);
+                app->playlist_view->style->bg, 0L);
         g_object_set (G_OBJECT (cell), "background-gdk",
-                ((Application*)data)->playlist_view->style->bg, 0L);
+                app->playlist_view->style->bg, 0L);
         g_object_set (G_OBJECT (cell), "mode", pld->edit_mode
                 ? GTK_CELL_RENDERER_MODE_EDITABLE
                 : GTK_CELL_RENDERER_MODE_INERT, 0L);
@@ -738,7 +739,7 @@ GtkWidget * createTreeView (Application * app) {
     g_signal_connect(G_OBJECT (sel),
             "changed", G_CALLBACK (cb_selection_changed), app);
     gtk_tree_view_column_set_cell_data_func (col, app->playlist_cell_renderer,
-            cb_treeCellDataFunc, app, false);
+            (GtkTreeCellDataFunc)cb_treeCellDataFunc, app, false);
 
     gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (view), col);
