@@ -38,7 +38,7 @@ class UnixProcess;
 /*
  * Base class for all backend processes
  */
-class KMPLAYER_EXPORT Process {
+class KMPLAYER_NO_EXPORT Process {
 public:
     enum State {
         NotRunning = 0, Ready, Buffering, Playing, Paused
@@ -165,7 +165,7 @@ public:
  */
 class MPlayer : public Process, public UnixProcessListener {
 public:
-    MPlayer (ProcessNotify * ctrl, bool xv);
+    MPlayer (ProcessNotify *ctrl, const char *name);
     ~MPlayer ();
     virtual bool play (NodePtr mrl);
     virtual bool pause ();
@@ -205,57 +205,6 @@ private:
     bool wait_for_pause;
 };
 
-/*
- * MM backend using dbus to control com.nokia.osso_media_server
- */
-class OssoMediaServer : public Process {
-public:
-    OssoMediaServer (ProcessNotify * ctrl, osso_context_t * context, bool xv);
-    ~OssoMediaServer ();
-public: //slots:
-    virtual bool play (NodePtr mrl);
-    virtual bool pause ();
-    virtual bool ready (unsigned int);
-    virtual bool stop ();
-    virtual bool quit ();
-    virtual bool seek (int pos, bool absolute);
-    virtual bool volume (int pos, bool absolute);
-    virtual bool saturation (int pos, bool absolute);
-    virtual bool hue (int pos, bool absolute);
-    virtual bool contrast (int pos, bool absolute);
-    virtual bool brightness (int pos, bool absolute);
-    virtual void setVideoWindow (int x, int y, int w, int h);
-    // called from dbus callbacks
-    void processPlaying ();
-    void processPaused ();
-    void processStopped ();
-    void processBuffering (int perc);
-    void setLength (int len);
-    const char * currentMediaServer () const { return current_service; }
-    osso_context_t * ossoContext () const { return m_osso_context; }
-    const char *dbusFilter () const { return dbus_filter; }
-    bool retry ();
-    DBusPendingCall * play_pending;
-    DBusPendingCall * pos_pending;
-    DBusPendingCall * seek_pending;
-    String stream_name;
-    static const char *myname;
-    void updateVideoSize ();
-private:
-    osso_context_t * m_osso_context;
-    IRect m_rect;  // see setVideoWindow (..)
-    IRect m_cur_rect; // last real setting
-    double m_volume;
-    const char *current_service;
-    const char *dbus_filter;
-    bool have_played;
-    bool have_played_stream;
-    bool try_audio_only;
-    bool first_time;
-    int retry_timer;
-    int pos_timer;
-};
-
 #ifdef __ARMEL__
 
 class NpStream;
